@@ -32,15 +32,3 @@ class ChatbotGPT:
         #  ask the user to give input
         prompt = input("You: ")
         return self.get_response(prompt)
-
-
-if __name__ == "__main__":
-    # Set up your OpenAI API credentials
-    key = "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"
-    chatbot = ChatbotGPT(key)
-    while True:
-        print("Chatbot: ", chatbot.ask())
-
-
-
-
